//****************************************************************************
//	
//	Copyright 2018 by WinSystems Inc.
//
//****************************************************************************
//
//	Name	 : getall.cpp
//
//	Project	 : PCM-MIO Console Application
//
//	Author	 : Paul DeMetrotion
//
//****************************************************************************
//
//	  Date		  Rev	                Description
//	--------    -------	   ---------------------------------------------
//	03/09/18	  1.0		Original Release
//
//****************************************************************************

#include <stdio.h>
#include <stdlib.h>  
#include <tchar.h>  
#include <windows.h>
#include "pcmmioadDLL.h"

#define MAJOR_VER   1
#define MINOR_VER   0
#define DEVICE      1

int _tmain(int argc, _TCHAR* argv[])
{
    float adcChVoltage[16];
    int dllReturn = SUCCESS;

    printf("PCM-MIO Application : getall\n");
    printf("Version %d.%d\n\n", MAJOR_VER, MINOR_VER);

    if (argc > 1)
    {
        printf("Usage error:\n");
        printf("  getall\n");
        exit(1);
    }

    dllReturn = InitializeSession(DEVICE);

    if (dllReturn)
    {
        printf("Error initializing device.\n");
        exit(dllReturn);
    }
    else   
    {
        printf("Device opened.\n");
    }

    // configure all 16 adc channels
    for (int i = 0; i < 16; i++) {
        dllReturn = AdcSetChannelMode(DEVICE, i, ADC_SINGLE_ENDED, ADC_BIPOLAR, ADC_TOP_10V);

        if (dllReturn)
        {
            printf("Error configuring ADC channel %d.\n", i);
            exit(dllReturn);
        }
    }

    printf("All ADC channels configured.\n\n");

    // read all channels
    dllReturn = AdcGetAllChannelVoltages(DEVICE, adcChVoltage);

    if (dllReturn)
    {
        printf("Error reading all ADC channels.\n");
        exit(dllReturn);
    }
    else
    {
        for (int i = 0; i < 16; i++)
            printf("ADC channel %d Voltage = %.3f.\n", i, adcChVoltage[i]);
    }

    dllReturn = CloseSession(DEVICE);

    if (dllReturn)
    {
        printf("Error closing device.\n");
        exit(dllReturn);
    }
    else
    {
        printf("Device closed.\n");
    }

    return(0);
}
