//****************************************************************************
//	
//	Copyright 2018 by WinSystems Inc.
//
//****************************************************************************
//
//	Name	 : getvolt.cpp
//
//	Project	 : PCM-MIO Console Application
//
//	Author	 : Paul DeMetrotion
//
//****************************************************************************
//
//	  Date		  Rev	                Description
//	--------    -------	   ---------------------------------------------
//	03/09/18	  1.0		Original Release
//
//****************************************************************************

#include <stdio.h>
#include <stdlib.h>  
#include <tchar.h>  
#include <windows.h>
#include "pcmmioadDLL.h"

#define MAJOR_VER   1
#define MINOR_VER   0
#define DEVICE      1

void print_usage_and_exit(void)
{
    printf("Usage error:\n");
    printf("  getvolt <channel number>\n");
    printf("  Channel must be between 0 and 15\n");
    printf("  If no channel entry, default is ch 0\n");
    exit(1);
}

int _tmain(int argc, _TCHAR* argv[])
{
    int channel = 0; // default channel
    float chVoltage;
    int dllReturn = SUCCESS;

    printf("PCM-MIO Application : getvolt\n");
    printf("Version %d.%d\n\n", MAJOR_VER, MINOR_VER);

    if (argc > 2)
        print_usage_and_exit();
    else if (argc == 2)
    {
        channel = _ttoi(argv[1]); // change channel

        if (channel < 0 || channel > 15)
            print_usage_and_exit();
    }

    dllReturn = InitializeSession(DEVICE);

    if (dllReturn)
    {
        printf("Error initializing device.\n");
        exit(dllReturn);
    }
    else   
    {
        printf("Device opened.\n");
    }

    // set channel mode
    dllReturn = AdcSetChannelMode(DEVICE, channel, ADC_SINGLE_ENDED, ADC_BIPOLAR, ADC_TOP_10V);

    if (dllReturn)
    {
        printf("Error configuring ADC channel %d.\n", channel);
        exit(dllReturn);
    }
    else
    {
        printf("Channel %d configured.\n", channel);
    }

    // get voltage
    dllReturn = AdcGetChannelVoltage(DEVICE, channel, &chVoltage);

    if (dllReturn)
    {
        printf("Error reading ADC channel %d.\n", channel);
        exit(dllReturn);
    }
    else
    {
        printf("Channel %d Voltage = %.6f.\n", channel, chVoltage);
    }

    dllReturn = CloseSession(DEVICE);

    if (dllReturn)
    {
        printf("Error closing device.\n");
        exit(dllReturn);
    }
    else
    {
        printf("Device closed.\n");
    }

    return(0);
}
