//****************************************************************************
//	
//	Copyright 2018 by WinSystems Inc.
//
//****************************************************************************
//
//	Name	 : pcmmioadDLL.h
//
//	Project	 : PCM-MIO-AD Windows DLL
//
//	Author	 : Paul DeMetrotion
//
//****************************************************************************
//
//	  Date		  Rev	                Description
//	--------    -------	   ---------------------------------------------
//	03/09/18	  1.0		Original Release of DLL	
//
//****************************************************************************

#ifndef _PCMMIOAD_DLL_H_
#define _PCMMIOAD_DLL_H_

#if defined DLL_EXPORT
#define DECLDIR __declspec(dllexport)
#else
#define DECLDIR __declspec(dllimport)
#endif  // DLL_EXPORT

extern "C"
{
    DECLDIR int InitializeSession(unsigned int device);
    DECLDIR int CloseSession(unsigned int device);

    // DIO functions
    DECLDIR int DioResetDevice(unsigned int device);
    DECLDIR int DioSetIoMask(unsigned int device, unsigned int *portState);
    DECLDIR int DioGetIoMask(unsigned int device, unsigned int *portState);
    DECLDIR int DioReadAllPorts(unsigned int device, unsigned int *readValueArray);
    DECLDIR int DioReadPort(unsigned int device, int port, unsigned int *readValue);
    DECLDIR int DioReadBit(unsigned int device, int bit, unsigned int *bitValue);
    DECLDIR int DioSetBit(unsigned int device, int bit);
    DECLDIR int DioClearBit(unsigned int device, int bit);
    DECLDIR int DioWritePort(unsigned int device, int port, unsigned int writeValue);
    DECLDIR int DioWriteBit(unsigned int device, int bit, unsigned int bitValue);
    DECLDIR int DioEnableInterrupt(unsigned int device, int bit, int edge);
    DECLDIR int DioDisableInterrupt(unsigned int device, int bit);
    DECLDIR int DioGetInterrupt(unsigned int device, unsigned int *irqArray);
    DECLDIR int DioWaitForInterrupt(unsigned int device, unsigned int *irqArray, unsigned long timeout);
    DECLDIR int DioLockPort(unsigned int device, int port);
    DECLDIR int DioUnlockPort(unsigned int device, int port);

    // ADC functions
    DECLDIR int AdcSetChannelMode(unsigned int device, unsigned int channel, int mode, int duplex, int range);
    DECLDIR int AdcGetChannelValue(unsigned int device, unsigned int channel, unsigned short *value);
    DECLDIR int AdcGetChannelVoltage(unsigned int device, unsigned int channel, float *voltage);
    DECLDIR int AdcGetAllChannelValues(unsigned int device, unsigned short *valBuf);
    DECLDIR int AdcGetAllChannelVoltages(unsigned int device, float *voltBuf);
    DECLDIR int AdcAutoGetChannelVoltage(unsigned int device, unsigned int channel, float *voltage);
    DECLDIR int AdcConvertSingleChannelRepeated(unsigned int device, unsigned int channel, int count, unsigned short *valBuf);
    DECLDIR int AdcBufferedChannelConversions(unsigned int device, unsigned int *chanBuf, unsigned short *outBuf);
    DECLDIR int AdcConvertToVolts(unsigned int device, unsigned int channel, int value, float *voltage);
    DECLDIR int AdcEnableInterrupt(unsigned int device, unsigned int channel);
    DECLDIR int AdcDisableInterrupt(unsigned int device, unsigned int channel);
    DECLDIR int AdcWaitForConversion(unsigned int device, unsigned int channel, unsigned short *value, unsigned long timeout);
    DECLDIR int AdcWriteCommand(unsigned int device, unsigned int channel, unsigned int adcCommand);
    DECLDIR int AdcWaitForReady(unsigned int device, unsigned int channel);
    DECLDIR int AdcReadData(unsigned int device, unsigned int channel, unsigned short *adcData);
    DECLDIR int AdcStartConversion(unsigned int device, unsigned int channel);
}

typedef enum {
    SUCCESS = 0,
    DRIVER_ERROR,
    ACCESS_ERROR,
    INVALID_HANDLE,
    INVALID_PARAMETER,
    TIMEOUT_ERROR
} ErrorCodes;

typedef enum {
    FALLING_EDGE = 0,
    RISING_EDGE
} IrqEdge;

typedef enum {
    ADC_DIFFERENTIAL = 0,
    ADC_SINGLE_ENDED
} AdcMode;

typedef enum {
    ADC_CH0_SELECT = 0,
    ADC_CH2_SELECT,
    ADC_CH4_SELECT,
    ADC_CH6_SELECT,
    ADC_CH1_SELECT,
    ADC_CH3_SELECT,
    ADC_CH5_SELECT,
    ADC_CH7_SELECT
} AdcChSelect;

typedef enum {
    ADC_BIPOLAR = 0,
    ADC_UNIPOLAR
} AdcDuplex;

typedef enum {
    ADC_TOP_5V = 0,
    ADC_TOP_10V
} AdcRange;

#endif  // _PCMMIOAD_DLL_H_
